nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Hscapable

Enum Hscapable 

#[repr(u8)]
pub enum Hscapable { FAST_MODE_PLUS = 0, HIGH_SPEED = 1, }

Variants



FAST_MODE_PLUS = 0

Fast-mode plus. The I 2C interface will support Standard-mode, Fast-mode, and Fast-mode Plus, to the extent that the pin electronics support these modes. Any changes that need to be made to the pin controls, such as changing the drive strength or filtering, must be made by software via the IOCON register associated with each I2C pin,



HIGH_SPEED = 1

High-speed. In addition to Standard-mode, Fast-mode, and Fast-mode Plus, the I 2C interface will support High-speed mode to the extent that the pin electronics support these modes. See Section 25.7.2.2 for more information.

Implementations

Source

impl Hscapable

pub const fn from_bits(val: u8) -> Hscapable

pub const fn to_bits(self) -> u8