#[repr(u8)]pub enum Monnack {
ACKNOWLEDGED = 0,
NOT_ACKNOWLEDGED = 1,
}Variants
ACKNOWLEDGED = 0
Acknowledged. The data currently being provided by the Monitor function was acknowledged by at least one master or slave receiver.
NOT_ACKNOWLEDGED = 1
Not acknowledged. The data currently being provided by the Monitor function was not acknowledged by any receiver.
Implementations