#[repr(u8)]pub enum Mstcontinue {
NO_EFFECT = 0,
CONTINUE = 1,
}Variants
NO_EFFECT = 0
No effect.
CONTINUE = 1
Continue. Informs the Master function to continue to the next operation. This must done after writing transmit data, reading received data, or any other housekeeping related to the next bus operation.
Implementations
Sourceimpl Mstcontinue
impl Mstcontinue