#[repr(u8)]pub enum Mstpending {
IN_PROGRESS = 0,
PENDING = 1,
}Variants
IN_PROGRESS = 0
In progress. Communication is in progress and the Master function is busy and cannot currently accept a command.
PENDING = 1
Pending. The Master function needs software service or is in the idle state. If the master is not in the idle state, it is waiting to receive or transmit data or the NACK bit.
Implementations
Sourceimpl Mstpending
impl Mstpending